@@ -29,15 +29,15 @@ class CBInfoResponse:
         self.info_response_dict: Dict = {
             'schema_version': self.info_schema_version,
             'identity': identity,
-            'request_id': request_id,
-            'architectures': []
+            'request_id': request_id
         }
 
     def set_info_response(
         self, package: str, source_ip: str, is_running: bool,
         arch: str, dist: str, binary_packages: List[str] = [],
-        log_file: str = 'unknown', solver_file: str = 'unknown',
-        utc_modification_time: str = 'unknown', build_status: str = 'unknown'
+        prepare_log_file: str = 'unknown', log_file: str = 'unknown',
+        solver_file: str = 'unknown', utc_modification_time: str = 'unknown',
+        build_status: str = 'unknown'
     ) -> None:
         self.info_response_dict = {
             **self.info_response_dict,
@@ -47,6 +47,7 @@ class CBInfoResponse:
             'arch': arch,
             'dist': dist,
             'binary_packages': binary_packages,
+            'prepare_log_file': prepare_log_file,
             'log_file': log_file,
             'solver_file': solver_file,
             'utc_modification_time': utc_modification_time,
@@ -54,11 +55,12 @@ class CBInfoResponse:
         }
 
     def set_info_response_result(
-        self, binary_packages: List[str], log_file: str,
+        self, binary_packages: List[str], prepare_log_file: str, log_file: str,
         solver_file: str, utc_modification_time: str,
         build_status: str
     ) -> None:
         self.info_response_dict['binary_packages'] = binary_packages
+        self.info_response_dict['prepare_log_file'] = prepare_log_file
         self.info_response_dict['log_file'] = log_file
         self.info_response_dict['solver_file'] = solver_file
         self.info_response_dict['utc_modification_time'] = utc_modification_time
